@@ -8,8 +8,27 @@ import textwrap
 import json
 import signal
 import ast
+from pygments import highlight
+from pygments.style import Style
+from pygments.token import (Name, Number, String, Keyword)
+from pygments.lexers import JsonLexer
+from pygments.formatters import Terminal256Formatter
 
-__version__ = '1.0.0'
+__version__ = '1.1.2'
+
+
+class JelloStyle(Style):
+    BLUE = '#2c5dcd'
+    GRAY = '#4d4d4d'
+    PURPLE = '#5918bb'
+    GREEN = '#00cc00'
+
+    styles = {
+        Name.Tag: f'bold {BLUE}',     # key names
+        Keyword: GRAY,                # true, false, null
+        Number: PURPLE,               # int, float
+        String: GREEN                 # string
+    }
 
 
 def ctrlc(signum, frame):
@@ -21,19 +40,28 @@ def get_stdin():
     """return STDIN data"""
     if sys.stdin.isatty():
         return None
+    else:
+        return sys.stdin.read()
 
-    return sys.stdin.read()
+
+def stdout_is_tty():
+    """returns True if stdout is a TTY. False if output is being piped to another program"""
+    if sys.stdout.isatty():
+        return True
+    else:
+        return False
 
 
 def helptext():
     print_error(textwrap.dedent('''\
         jello:   query JSON at the command line with python syntax
 
-        Usage:  <JSON Data> | jello [OPTIONS] QUERY
+        Usage:  <JSON Data> | jello [OPTIONS] [QUERY]
 
                 -c    compact JSON output
                 -i    initialize environment with .jelloconf.py in ~ (linux) or %appdata% (Windows)
                 -l    output as lines suitable for assignment to a bash array
+                -m    monochrome output
                 -n    print selected null values
                 -r    raw string output (no quotes)
                 -v    version info
@@ -53,12 +81,7 @@ def print_error(message):
     sys.exit(1)
 
 
-def lines(data):
-    """This function is deprecated. Instead, use the -l option"""
-    return data
-
-
-def create_json(data, compact=False, nulls=None, lines=None, raw=None):
+def create_json(data, compact=None, nulls=None, raw=None, lines=None):
     if isinstance(data, dict):
         if compact or lines:
             return json.dumps(data)
@@ -124,7 +147,7 @@ def create_json(data, compact=False, nulls=None, lines=None, raw=None):
             return f'"{data}"'
 
 
-def pyquery(data, query, initialize=None):
+def pyquery(data, query, initialize=None, compact=None, nulls=None, raw=None, lines=None, mono=None):
     _ = data
     jelloconf = ''
 
@@ -145,21 +168,30 @@ def pyquery(data, query, initialize=None):
     query = jelloconf + query
     output = None
 
-    # f = io.StringIO()
-    # try:
-    #     with redirect_stdout(f):
-    #         print(exec(compile(query, '<string>', 'exec')))
-    #         output = f.getvalue()[0:-6]
-
     try:
+        # extract jello options from .jelloconf.py (compact, raw, lines, nulls, mono)
+        for expr in ast.parse(jelloconf).body:
+            if isinstance(expr, ast.Assign):
+                if expr.targets[0].id == 'compact':
+                    compact = eval(compile(ast.Expression(expr.value), '<string>', "eval"))
+                if expr.targets[0].id == 'raw':
+                    raw = eval(compile(ast.Expression(expr.value), '<string>', "eval"))
+                if expr.targets[0].id == 'lines':
+                    lines = eval(compile(ast.Expression(expr.value), '<string>', "eval"))
+                if expr.targets[0].id == 'nulls':
+                    nulls = eval(compile(ast.Expression(expr.value), '<string>', "eval"))
+                if expr.targets[0].id == 'mono':
+                    mono = eval(compile(ast.Expression(expr.value), '<string>', "eval"))
+
+        # run the query
         block = ast.parse(query, mode='exec')
-
-        # assumes last node is an expression
-        last = ast.Expression(block.body.pop().value)
-
+        last = ast.Expression(block.body.pop().value)    # assumes last node is an expression
         exec(compile(block, '<string>', mode='exec'))
         output = eval(compile(last, '<string>', mode='eval'))
 
+        # need to return compact, nulls, raw, lines, mono in case they were changed in .jelloconf.py
+        return (output, compact, nulls, raw, lines, mono)
+
     except KeyError as e:
         print_error(textwrap.dedent(f'''\
             jello:  Key does not exist: {e}
@@ -202,8 +234,6 @@ def pyquery(data, query, initialize=None):
                     output: {output}
         '''))
 
-    return output
-
 
 def load_json(data):
     try:
@@ -218,7 +248,7 @@ def load_json(data):
                 entry = json.loads(jsonline)
                 data_list.append(entry)
             except Exception as e:
-                # can't parse the data. Throw a nice message and quit
+                # can't parse the data. Throw an error and quit
                 print_error(textwrap.dedent(f'''\
                     jello:  JSON Load Exception: {e}
                             Cannot parse line {i + 1} (Not JSON or JSON Lines data):
@@ -230,7 +260,7 @@ def load_json(data):
     return json_dict
 
 
-def main(data=None, query='_', compact=None, lines=None, nulls=None, raw=None, version_info=None, helpme=None, initialize=None):
+def main(data=None, query='_', initialize=None, version_info=None, helpme=None, compact=None, nulls=None, raw=None, lines=None, mono=None):
     # break on ctrl-c keyboard interrupt
     signal.signal(signal.SIGINT, ctrlc)
 
@@ -261,6 +291,7 @@ def main(data=None, query='_', compact=None, lines=None, nulls=None, raw=None, v
     compact = compact if not commandline else'c' in options
     initialize = initialize if not commandline else 'i' in options
     lines = lines if not commandline else 'l' in options
+    mono = mono if not commandline else 'm' in options
     nulls = nulls if not commandline else 'n' in options
     raw = raw if not commandline else 'r' in options
     version_info = version_info if not commandline else 'v' in options
@@ -275,19 +306,24 @@ def main(data=None, query='_', compact=None, lines=None, nulls=None, raw=None, v
     if data is None:
         print_error('jello:  missing piped JSON or JSON Lines data\n')
 
-    # lines() function is deprecated. If lines() is found, then call the -l lines option instead.
-    lines_warning = False
-    if query.find('lines(') != -1:
-        lines = True
-        lines_warning = True
+    # lines() function is deprecated. Warn and quit if detected.
+    if query and 'lines(' in query:
+        print_error('jello:  Error: lines() function is deprecated. Please use the -l option instead.\n')
 
     list_dict_data = load_json(data)
-    response = pyquery(list_dict_data, query, initialize=initialize)
+    # pulling variables back from pyquery since the user may have defined intialization options
+    # in their .jelloconf.py file
+    response, compact, nulls, raw, lines, mono = pyquery(list_dict_data, query, initialize=initialize,
+                                                         compact=compact, nulls=nulls, raw=raw, lines=lines,
+                                                         mono=mono)
     output = create_json(response, compact=compact, nulls=nulls, raw=raw, lines=lines)
 
     try:
         if commandline:
-            print(output)
+            if not mono and not lines and stdout_is_tty():
+                print(highlight(output, JsonLexer(), Terminal256Formatter(style=JelloStyle))[0:-1])
+            else:
+                print(output)
         else:
             return output
 
@@ -299,9 +335,6 @@ def main(data=None, query='_', compact=None, lines=None, nulls=None, raw=None, v
                     output: {output}
         '''))
 
-    if lines_warning:
-        print('\njello:  Warning: lines() function is deprecated. Please use the -l option instead.\n', file=sys.stderr)
-
 
 if __name__ == '__main__':
     main()
